/**
 * Parsed output of `nginx -V` returned by {@link nginxVersionInfo}.
 */
export interface NginxVersionInfo {
    /**
     * Nginx version number (e.g. `'1.18.0'`).
     */
    version: string;
    /**
     * A record of modules the nginx was built with or without.
     *
     * @example
     * {
     *   http_fastcgi: 'without',
     *   http_geoip: 'with-dynamic',
     *   http_ssl: 'with',
     * }
     */
    modules: Record<string, ModuleFlag>;
}
export declare type ModuleFlag = 'with' | 'with-dynamic' | 'without';
/**
 * Executes the nginx binary `nginxBinPath` with option `-V` and returns parsed
 * version and info about the modules it was compiled with(out).
 */
export declare function nginxVersionInfo(nginxBinPath: string): Promise<NginxVersionInfo>;
//# sourceMappingURL=nginxVersionInfo.d.ts.map